[POLICY-73] replace openecomp for policy-engine

Change-Id: I54072f6bcd388c0e05562614ee89b4ae7ad67004
Signed-off-by: Guo Ruijing <ruijing.guo@intel.com>
Signed-off-by: Pamela Dragosh <pdragosh@research.att.com>
diff --git a/BRMSGateway/config.properties b/BRMSGateway/config.properties
index 3f6f6f6..762f0ff 100644
--- a/BRMSGateway/config.properties
+++ b/BRMSGateway/config.properties
@@ -1,6 +1,6 @@
 ###
 # ============LICENSE_START=======================================================
-# ECOMP Policy Engine
+# ONAP Policy Engine
 # ================================================================================
 # Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 # ================================================================================
@@ -48,11 +48,11 @@
 
 ## GroupNames can be comma separated values. 
 groupNames = default, vFW , vDNS
-default.groupID = org.openecomp.policy-engine
+default.groupID = org.onap.policy-engine
 default.artifactID = drlPDPGroup
-vFW.groupID= org.openecomp.policy-engine.drools.vFW
+vFW.groupID= org.onap.policy-engine.drools.vFW
 vFW.artifactID= policy-vFW-rules
-vDNS.groupID= org.openecomp.policy-engine.drools.vDNS
+vDNS.groupID= org.onap.policy-engine.drools.vDNS
 vDNS.artifactID= policy-vDNS-rules
 
 #Integrity Monitor values
diff --git a/BRMSGateway/config/policyLogger.properties b/BRMSGateway/config/policyLogger.properties
index d3d4772..d6b0b39 100644
--- a/BRMSGateway/config/policyLogger.properties
+++ b/BRMSGateway/config/policyLogger.properties
@@ -1,6 +1,6 @@
 ###
 # ============LICENSE_START=======================================================
-# ECOMP Policy Engine
+# ONAP Policy Engine
 # ================================================================================
 # Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 # ================================================================================
diff --git a/BRMSGateway/policyLogger.properties b/BRMSGateway/policyLogger.properties
index d3d4772..d6b0b39 100644
--- a/BRMSGateway/policyLogger.properties
+++ b/BRMSGateway/policyLogger.properties
@@ -1,6 +1,6 @@
 ###
 # ============LICENSE_START=======================================================
-# ECOMP Policy Engine
+# ONAP Policy Engine
 # ================================================================================
 # Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 # ================================================================================
diff --git a/BRMSGateway/pom.xml b/BRMSGateway/pom.xml
index 5512f7a..b398f37 100644
--- a/BRMSGateway/pom.xml
+++ b/BRMSGateway/pom.xml
@@ -1,6 +1,6 @@
 <!--
   ============LICENSE_START=======================================================
-  ECOMP Policy Engine
+  ONAP Policy Engine
   ================================================================================
   Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
   ================================================================================
@@ -22,7 +22,7 @@
 	xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
 	<modelVersion>4.0.0</modelVersion>
 	<parent>
-		<groupId>org.openecomp.policy.engine</groupId>
+		<groupId>org.onap.policy.engine</groupId>
 		<artifactId>PolicyEngineSuite</artifactId>
 		<version>1.1.0-SNAPSHOT</version>
 	</parent>
@@ -30,7 +30,7 @@
 	<description>This application will take in BRMS rules and acts as interface between PR and PDP XACML</description>
 	<dependencies>
 		<dependency>
-			<groupId>org.openecomp.policy.engine</groupId>
+			<groupId>org.onap.policy.engine</groupId>
 			<artifactId>PolicyEngineAPI</artifactId>
 			<version>${project.version}</version>
 			<exclusions>
@@ -51,7 +51,7 @@
 			<version>2.2</version>
 		</dependency>
 		<dependency>
-			<groupId>org.openecomp.policy.common</groupId>
+			<groupId>org.onap.policy.common</groupId>
 			<artifactId>integrity-monitor</artifactId>
 			<version>${common-modules.version}</version>
 		</dependency>
@@ -109,7 +109,7 @@
 						<manifest>
 							<addClasspath>true</addClasspath>
 							<classpathPrefix>lib/</classpathPrefix>
-							<mainClass>org.openecomp.policy.brmsInterface.BRMSGateway</mainClass>
+							<mainClass>org.onap.policy.brmsInterface.BRMSGateway</mainClass>
 						</manifest>
 					</archive>
 					<descriptorRefs>
diff --git a/BRMSGateway/src/main/resources/META-INF/persistenceBRMS.xml b/BRMSGateway/src/main/resources/META-INF/persistenceBRMS.xml
index 446e734..99e6b92 100644
--- a/BRMSGateway/src/main/resources/META-INF/persistenceBRMS.xml
+++ b/BRMSGateway/src/main/resources/META-INF/persistenceBRMS.xml
@@ -24,7 +24,7 @@
 	xsi:schemaLocation="http://xmlns.jcp.org/xml/ns/persistence http://xmlns.jcp.org/xml/ns/persistence/persistence_2_1.xsd">
 	<persistence-unit name="BRMSGW" transaction-type="RESOURCE_LOCAL">
 		<provider>org.eclipse.persistence.jpa.PersistenceProvider</provider>
-		<class>org.openecomp.policy.brmsInterface.jpa.BRMSGroupInfo</class>
-		<class>org.openecomp.policy.brmsInterface.jpa.BRMSPolicyInfo</class>
+		<class>org.onap.policy.brmsInterface.jpa.BRMSGroupInfo</class>
+		<class>org.onap.policy.brmsInterface.jpa.BRMSPolicyInfo</class>
 	</persistence-unit>
 </persistence>
\ No newline at end of file
diff --git a/BRMSGateway/src/main/resources/log4j.properties b/BRMSGateway/src/main/resources/log4j.properties
index 71f3596..9ec89ea 100644
--- a/BRMSGateway/src/main/resources/log4j.properties
+++ b/BRMSGateway/src/main/resources/log4j.properties
@@ -1,6 +1,6 @@
 ###
 # ============LICENSE_START=======================================================
-# ECOMP Policy Engine
+# ONAP Policy Engine
 # ================================================================================
 # Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 # ================================================================================
diff --git a/BRMSGateway/src/main/resources/logback.xml b/BRMSGateway/src/main/resources/logback.xml
index 2cae6c8..3fa0a65 100644
--- a/BRMSGateway/src/main/resources/logback.xml
+++ b/BRMSGateway/src/main/resources/logback.xml
@@ -1,6 +1,6 @@
 <!--
   ============LICENSE_START=======================================================
-  ECOMP Policy Engine
+  ONAP Policy Engine
   ================================================================================
   Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
   ================================================================================
@@ -27,7 +27,7 @@
   <property name="debugDir" value="logs" />
   
   <!--  specify the component name 
-    <ECOMP-component-name>::= "MSO" | "DCAE" | "ASDC " | "AAI" |"Policy" | "SDNC" | "AC"  -->
+    <ONAP-component-name>::= "MSO" | "DCAE" | "ASDC " | "AAI" |"Policy" | "SDNC" | "AC"  -->
   <property name="componentName" value="Policy"></property>
   <property name="subComponentName" value="BRMSGateway"></property>
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSGateway.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSGateway.java
similarity index 88%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSGateway.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSGateway.java
index 88810fb..0b4058d 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSGateway.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSGateway.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -18,20 +18,20 @@
  * ============LICENSE_END=========================================================
  */
 
-package org.openecomp.policy.brmsInterface;
+package org.onap.policy.brmsInterface;
 
-import org.openecomp.policy.api.NotificationScheme;
-import org.openecomp.policy.api.PolicyEngine;
+import org.onap.policy.api.NotificationScheme;
+import org.onap.policy.api.PolicyEngine;
 
 //import org.apache.log4j.Logger;
 
 //import org.apache.commons.logging.Log;
 //import org.apache.commons.logging.LogFactory;
 
-import org.openecomp.policy.common.logging.flexlogger.FlexLogger;
-import org.openecomp.policy.common.logging.flexlogger.Logger;
+import org.onap.policy.common.logging.flexlogger.FlexLogger;
+import org.onap.policy.common.logging.flexlogger.Logger;
 
-import org.openecomp.policy.xacml.api.XACMLErrorConstants;
+import org.onap.policy.xacml.api.XACMLErrorConstants;
 
 
 /**
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSHandler.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSHandler.java
similarity index 85%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSHandler.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSHandler.java
index f5f78a9..305f64d 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSHandler.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSHandler.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -18,24 +18,24 @@
  * ============LICENSE_END=========================================================
  */
 
-package org.openecomp.policy.brmsInterface;
+package org.onap.policy.brmsInterface;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.openecomp.policy.api.ConfigRequestParameters;
-import org.openecomp.policy.api.LoadedPolicy;
-import org.openecomp.policy.api.NotificationType;
-import org.openecomp.policy.api.PDPNotification;
-import org.openecomp.policy.api.PolicyConfig;
-import org.openecomp.policy.api.PolicyConfigStatus;
-import org.openecomp.policy.api.PolicyEngine;
-import org.openecomp.policy.api.PolicyException;
-import org.openecomp.policy.api.RemovedPolicy;
-import org.openecomp.policy.common.logging.flexlogger.FlexLogger;
-import org.openecomp.policy.common.logging.flexlogger.Logger;
-import org.openecomp.policy.utils.BackUpHandler;
-import org.openecomp.policy.xacml.api.XACMLErrorConstants;
+import org.onap.policy.api.ConfigRequestParameters;
+import org.onap.policy.api.LoadedPolicy;
+import org.onap.policy.api.NotificationType;
+import org.onap.policy.api.PDPNotification;
+import org.onap.policy.api.PolicyConfig;
+import org.onap.policy.api.PolicyConfigStatus;
+import org.onap.policy.api.PolicyEngine;
+import org.onap.policy.api.PolicyException;
+import org.onap.policy.api.RemovedPolicy;
+import org.onap.policy.common.logging.flexlogger.FlexLogger;
+import org.onap.policy.common.logging.flexlogger.Logger;
+import org.onap.policy.utils.BackUpHandler;
+import org.onap.policy.xacml.api.XACMLErrorConstants;
 
 /**
  * BRMSHandler: Notification Handler which listens for PDP Notifications. 
@@ -60,7 +60,7 @@
 	/*
 	 * This Method is executed upon notification by the Policy Engine API Notification. 
 	 * (non-Javadoc)
-	 * @see org.openecomp.policy.utils.BackUpHandler#notificationReceived(org.openecomp.policy.api.PDPNotification)
+	 * @see org.onap.policy.utils.BackUpHandler#notificationReceived(org.onap.policy.api.PDPNotification)
 	 */
 	@Override
 	public void notificationReceived(PDPNotification notification) {
@@ -115,7 +115,7 @@
 	/*
 	 * This method is executed if BRMSGW is "MASTER" 
 	 * (non-Javadoc)
-	 * @see org.openecomp.policy.utils.BackUpHandler#runOnNotification(org.openecomp.policy.api.PDPNotification)
+	 * @see org.onap.policy.utils.BackUpHandler#runOnNotification(org.onap.policy.api.PDPNotification)
 	 */
 	public void runOnNotification(PDPNotification notification){
 		if(notification.getNotificationType().equals(NotificationType.REMOVE)){
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSPush.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSPush.java
similarity index 97%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSPush.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSPush.java
index def57e2..c244938 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/BRMSPush.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/BRMSPush.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -18,7 +18,7 @@
  * ============LICENSE_END=========================================================
  */
 
-package org.openecomp.policy.brmsInterface;
+package org.onap.policy.brmsInterface;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -68,22 +68,22 @@
 import org.codehaus.plexus.util.IOUtil;
 import org.codehaus.plexus.util.WriterFactory;
 import org.eclipse.persistence.config.PersistenceUnitProperties;
-import org.openecomp.policy.api.PEDependency;
-import org.openecomp.policy.api.PolicyException;
-import org.openecomp.policy.brmsInterface.jpa.BRMSGroupInfo;
-import org.openecomp.policy.brmsInterface.jpa.BRMSPolicyInfo;
-import org.openecomp.policy.brmsInterface.jpa.DependencyInfo;
-import org.openecomp.policy.common.im.AdministrativeStateException;
-import org.openecomp.policy.common.im.IntegrityMonitor;
-import org.openecomp.policy.common.logging.eelf.MessageCodes;
-import org.openecomp.policy.common.logging.eelf.PolicyLogger;
-import org.openecomp.policy.common.logging.flexlogger.FlexLogger;
-import org.openecomp.policy.common.logging.flexlogger.Logger;
-import org.openecomp.policy.utils.BackUpHandler;
-import org.openecomp.policy.utils.BackUpMonitor;
-import org.openecomp.policy.utils.BusPublisher;
-import org.openecomp.policy.utils.PolicyUtils;
-import org.openecomp.policy.xacml.api.XACMLErrorConstants;
+import org.onap.policy.api.PEDependency;
+import org.onap.policy.api.PolicyException;
+import org.onap.policy.brmsInterface.jpa.BRMSGroupInfo;
+import org.onap.policy.brmsInterface.jpa.BRMSPolicyInfo;
+import org.onap.policy.brmsInterface.jpa.DependencyInfo;
+import org.onap.policy.common.im.AdministrativeStateException;
+import org.onap.policy.common.im.IntegrityMonitor;
+import org.onap.policy.common.logging.eelf.MessageCodes;
+import org.onap.policy.common.logging.eelf.PolicyLogger;
+import org.onap.policy.common.logging.flexlogger.FlexLogger;
+import org.onap.policy.common.logging.flexlogger.Logger;
+import org.onap.policy.utils.BackUpHandler;
+import org.onap.policy.utils.BackUpMonitor;
+import org.onap.policy.utils.BusPublisher;
+import org.onap.policy.utils.PolicyUtils;
+import org.onap.policy.xacml.api.XACMLErrorConstants;
 import org.sonatype.nexus.client.NexusClient;
 import org.sonatype.nexus.client.NexusClientException;
 import org.sonatype.nexus.client.NexusConnectionException;
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/ControllerPOJO.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/ControllerPOJO.java
similarity index 95%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/ControllerPOJO.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/ControllerPOJO.java
index 546925b..5a0679c 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/ControllerPOJO.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/ControllerPOJO.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -18,7 +18,7 @@
  * ============LICENSE_END=========================================================
  */
 
-package org.openecomp.policy.brmsInterface;
+package org.onap.policy.brmsInterface;
 
 import java.util.Map;
 
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/NotificationPOJO.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/NotificationPOJO.java
similarity index 95%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/NotificationPOJO.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/NotificationPOJO.java
index 116a7b4..75bbe8a 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/NotificationPOJO.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/NotificationPOJO.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -18,7 +18,7 @@
  * ============LICENSE_END=========================================================
  */
 
-package org.openecomp.policy.brmsInterface;
+package org.onap.policy.brmsInterface;
 
 import java.util.List;
 
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSGroupInfo.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSGroupInfo.java
similarity index 96%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSGroupInfo.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSGroupInfo.java
index 1c48950..6b4a2bf 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSGroupInfo.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSGroupInfo.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -17,7 +17,7 @@
  * limitations under the License.
  * ============LICENSE_END=========================================================
  */
-package org.openecomp.policy.brmsInterface.jpa;
+package org.onap.policy.brmsInterface.jpa;
 
 import javax.persistence.Column;
 import javax.persistence.Entity;
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSPolicyInfo.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSPolicyInfo.java
similarity index 95%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSPolicyInfo.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSPolicyInfo.java
index 5bc2728..c269e29 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/BRMSPolicyInfo.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/BRMSPolicyInfo.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -17,7 +17,7 @@
  * limitations under the License.
  * ============LICENSE_END=========================================================
  */
-package org.openecomp.policy.brmsInterface.jpa;
+package org.onap.policy.brmsInterface.jpa;
 
 import javax.persistence.Column;
 import javax.persistence.Entity;
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
diff --git a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/DependencyInfo.java b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/DependencyInfo.java
similarity index 91%
rename from BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/DependencyInfo.java
rename to BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/DependencyInfo.java
index 2d28cc2..753de52 100644
--- a/BRMSGateway/src/main/java/org/openecomp/policy/brmsInterface/jpa/DependencyInfo.java
+++ b/BRMSGateway/src/main/java/org/onap/policy/brmsInterface/jpa/DependencyInfo.java
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
  * ECOMP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
  * ================================================================================
@@ -17,12 +17,12 @@
  * limitations under the License.
  * ============LICENSE_END=========================================================
  */
-package org.openecomp.policy.brmsInterface.jpa;
+package org.onap.policy.brmsInterface.jpa;
 
 import java.util.List;
 import java.util.Map;
 
-import org.openecomp.policy.api.PEDependency;
+import org.onap.policy.api.PEDependency;
 
 public class DependencyInfo {
 	private Map<String, List<PEDependency>> dependencies;
@@ -1,6 +1,6 @@
 /*-
  * ============LICENSE_START=======================================================
- * ECOMP Policy Engine
+ * ONAP Policy Engine
  * ================================================================================
  * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.